<h1>RSSIngest</h1>
<p>
RSSIngest is a python module responsible for ingesting unprocessed 
news article metadata from a selection of RSS feeds as specified by 
the configuration file `config.yaml`.
</p>

<p>
Ash Prince, 2018.
</p>


